Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Dykstal2007-01-03 22:21:37 +0000
committerDavid Dykstal2007-01-03 22:21:37 +0000
commit1e23d32970abbdbac23b2fd8682e840d07e87caf (patch)
tree35d842cfc5da5ff3654d584f250c9a070d1c8f0c
parent6dda7b5817db37ae7f5620b8a81329dbce8f5964 (diff)
downloadorg.eclipse.tm-1e23d32970abbdbac23b2fd8682e840d07e87caf.tar.gz
org.eclipse.tm-1e23d32970abbdbac23b2fd8682e840d07e87caf.tar.xz
org.eclipse.tm-1e23d32970abbdbac23b2fd8682e840d07e87caf.zip
[168864] deleting ISystemUserIdConstants, removing all references to that.
-rw-r--r--rse/plugins/org.eclipse.rse.core/src/org/eclipse/rse/core/model/ISystemHostPool.java7
-rw-r--r--rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/RSEUIPlugin.java2
-rw-r--r--rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/SystemConnectionForm.java6
-rw-r--r--rse/plugins/org.eclipse.rse.ui/model/org/eclipse/rse/internal/model/SystemHostPool.java8
-rw-r--r--rse/plugins/org.eclipse.rse.ui/systems/org/eclipse/rse/core/ISystemUserIdConstants.java30
-rw-r--r--rse/tests/org.eclipse.rse.tests/src/org/eclipse/rse/tests/internal/RSEConnectionManager.java4
6 files changed, 17 insertions, 40 deletions
diff --git a/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/RSEUIPlugin.java b/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/RSEUIPlugin.java
index e3d6d50d1..f8d2c44fe 100644
--- a/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/RSEUIPlugin.java
+++ b/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/RSEUIPlugin.java
@@ -539,7 +539,7 @@ public class RSEUIPlugin extends SystemBasePlugin implements ISystemMessageProvi
// DY: defect 42101, description cannot be null
// null, // description
getLocalMachineName(), // userId
- ISystemUserIdConstants.USERID_LOCATION_DEFAULT_SYSTEMTYPE, null);
+ IRSEUserIdConstants.USERID_LOCATION_DEFAULT_SYSTEMTYPE, null);
*/
//}
//catch (Exception exc)
diff --git a/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/SystemConnectionForm.java b/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/SystemConnectionForm.java
index fd98282de..97d5e23a5 100644
--- a/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/SystemConnectionForm.java
+++ b/rse/plugins/org.eclipse.rse.ui/UI/org/eclipse/rse/ui/SystemConnectionForm.java
@@ -585,8 +585,10 @@ public class SystemConnectionForm
/**
* If a default userId was specified, the user may have been queried
- * where to put the userId. This returns one of the constants from
- * ISystemUserIdConstants
+ * where to put the userId. This returns one of the constants from
+ * IRSEUserIdConstants.
+ * @return the user id location
+ * @see IRSEUserIdConstants
*/
public int getUserIdLocation()
{
diff --git a/rse/plugins/org.eclipse.rse.ui/model/org/eclipse/rse/internal/model/SystemHostPool.java b/rse/plugins/org.eclipse.rse.ui/model/org/eclipse/rse/internal/model/SystemHostPool.java
index ba8debe77..3a2cb81ff 100644
--- a/rse/plugins/org.eclipse.rse.ui/model/org/eclipse/rse/internal/model/SystemHostPool.java
+++ b/rse/plugins/org.eclipse.rse.ui/model/org/eclipse/rse/internal/model/SystemHostPool.java
@@ -189,9 +189,10 @@ public class SystemHostPool extends RSEModelObject implements ISystemHostPool
* @param hostName ip name of host.
* @param description optional description of the connection. Can be null.
* @param defaultUserId userId to use as the default for the subsystems.
- * @param defaultUserIdLocation where to set the given default user Id. See ISystemUserIdConstants
+ * @param defaultUserIdLocation where to set the given default user Id. See IRSEUserIdConstants for values.
* @return SystemConnection object, or null if it failed to create
* because the aliasName is not unique. All other errors throw an exception.
+ * @see IRSEUserIdConstants
*/
public IHost createHost(String systemType, String aliasName, String hostName,
String description,String defaultUserId,int defaultUserIdLocation)
@@ -237,7 +238,8 @@ public class SystemHostPool extends RSEModelObject implements ISystemHostPool
* @param hostName ip name of host.
* @param description optional description of the connection. Can be null.
* @param defaultUserId userId to use as the default for the subsystems.
- * @param defaultUserIdLocation where to set the given default user Id. See ISystemUserIdConstants
+ * @param defaultUserIdLocation where to set the given default user Id. See IRSEUserIdConstants for values.
+ * @see IRSEUserIdConstants
*/
public void updateHost(IHost conn, String systemType,
String aliasName, String hostName,
@@ -262,7 +264,7 @@ public class SystemHostPool extends RSEModelObject implements ISystemHostPool
{
prefMgr.setDefaultUserId(systemType, defaultUserId);
}
- //else if (defaultUserIdLocation == ISystemUserIdConstants.USERID_LOCATION_DEFAULT_OVERALL)
+ //else if (defaultUserIdLocation == IRSEUserIdConstants.USERID_LOCATION_DEFAULT_OVERALL)
//{
//prefMgr.setDefaultUserId(defaultUserId);
//}
diff --git a/rse/plugins/org.eclipse.rse.ui/systems/org/eclipse/rse/core/ISystemUserIdConstants.java b/rse/plugins/org.eclipse.rse.ui/systems/org/eclipse/rse/core/ISystemUserIdConstants.java
deleted file mode 100644
index 00b284e9a..000000000
--- a/rse/plugins/org.eclipse.rse.ui/systems/org/eclipse/rse/core/ISystemUserIdConstants.java
+++ /dev/null
@@ -1,30 +0,0 @@
-/********************************************************************************
- * Copyright (c) 2000, 2006 IBM Corporation. All rights reserved.
- * This program and the accompanying materials are made available under the terms
- * of the Eclipse Public License v1.0 which accompanies this distribution, and is
- * available at http://www.eclipse.org/legal/epl-v10.html
- *
- * Initial Contributors:
- * The following IBM employees contributed to the Remote System Explorer
- * component that contains this file: David McKnight, Kushal Munir,
- * Michael Berger, David Dykstal, Phil Coulthard, Don Yantzi, Eric Simpson,
- * Emily Bruner, Mazen Faraj, Adrian Storisteanu, Li Ding, and Kent Hawley.
- *
- * Contributors:
- * {Name} (company) - description of contribution.
- ********************************************************************************/
-
-package org.eclipse.rse.core;
-/**
- * Constants for user Id management
- * @deprecated use {@link IRSEUserIdConstants} instead.
- */
-public interface ISystemUserIdConstants
-{
-
- public static final int USERID_LOCATION_NOTSET = 0;
- public static final int USERID_LOCATION_SUBSYSTEM = 1;
- public static final int USERID_LOCATION_CONNECTION = 2;
- public static final int USERID_LOCATION_DEFAULT_SYSTEMTYPE = 3;
- public static final int USERID_LOCATION_DEFAULT_OVERALL= 4;
-} \ No newline at end of file
diff --git a/rse/tests/org.eclipse.rse.tests/src/org/eclipse/rse/tests/internal/RSEConnectionManager.java b/rse/tests/org.eclipse.rse.tests/src/org/eclipse/rse/tests/internal/RSEConnectionManager.java
index 82e92f748..8ef88440b 100644
--- a/rse/tests/org.eclipse.rse.tests/src/org/eclipse/rse/tests/internal/RSEConnectionManager.java
+++ b/rse/tests/org.eclipse.rse.tests/src/org/eclipse/rse/tests/internal/RSEConnectionManager.java
@@ -24,7 +24,7 @@ import junit.framework.Assert;
import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
-import org.eclipse.rse.core.ISystemUserIdConstants;
+import org.eclipse.rse.core.IRSEUserIdConstants;
import org.eclipse.rse.core.PasswordPersistenceManager;
import org.eclipse.rse.core.RSECorePlugin;
import org.eclipse.rse.core.model.IHost;
@@ -225,7 +225,7 @@ public class RSEConnectionManager implements IRSEConnectionManager {
cause = null;
try {
- connection = systemRegistry.createHost(profileName, systemType, name, address, null, userId, ISystemUserIdConstants.USERID_LOCATION_CONNECTION, null);
+ connection = systemRegistry.createHost(profileName, systemType, name, address, null, userId, IRSEUserIdConstants.USERID_LOCATION_HOST, null);
} catch(Exception e) {
exception = e;
cause = e.getLocalizedMessage();

Back to the top
diff --git a/rse/plugins/org.eclipse.rse.core/src/org/eclipse/rse/core/model/ISystemHostPool.java b/rse/plugins/org.eclipse.rse.core/src/org/eclipse/rse/core/model/ISystemHostPool.java
index 769e83cb6..7218ef98d 100644
--- a/rse/plugins/org.eclipse.rse.core/src/org/eclipse/rse/core/model/ISystemHostPool.java
+++ b/rse/plugins/org.eclipse.rse.core/src/org/eclipse/rse/core/model/ISystemHostPool.java
@@ -18,6 +18,8 @@ package org.eclipse.rse.core.model;
import java.util.List;
+import org.eclipse.rse.core.IRSEUserIdConstants;
+
//
/**
@@ -69,12 +71,13 @@ public interface ISystemHostPool extends IRSEPersistableContainer {
* <p>
* @param conn SystemConnection to be updated
* @param systemType system type matching one of the system type names defined via the
- * systemType extension point.
+ * systemType extension point.
* @param aliasName unique connection name.
* @param hostName ip name of host.
* @param description optional description of the connection. Can be null.
* @param defaultUserId userId to use as the default for the subsystems.
* @param defaultUserIdLocation where to set the given default user Id. See ISystemUserIdConstants
*/
public void updateHost(IHost conn, String systemType, String aliasName, String hostName, String description, String defaultUserId, int defaultUserIdLocation) throws Exception;
@@ -69,12 +71,13 @@ public interface ISystemHostPool extends IRSEPersistableContainer {
* @param description optional description of the connection. Can be null.
* @param defaultUserId userId to use as the default for the subsystems.
- * @param defaultUserIdLocation where to set the given default user Id. See ISystemUserIdConstants
+ * @param defaultUserIdLocation where to set the given default user Id from IRSEUserIdConstants.
+ * @see IRSEUserIdConstants
*/
public void updateHost(IHost conn, String systemType, String aliasName, String hostName, String description, String defaultUserId, int defaultUserIdLocation) throws Exception;